@@ -1,2 +1,3 @@
-import pkg_resources
+import pkg_resources  # type: ignore[import]
+
 __version__ = pkg_resources.get_distribution("signal-export").version
